@@ -1,5 +1,3 @@
-import re
-
 from django.contrib.auth.decorators import login_required
 from stronghold import conf
 
@@ -15,8 +13,7 @@ class LoginRequiredMiddleware(object):
     each url in STRONGHOLD_PUBLIC_URLS must be a valid regex
     """
     def __init__(self, *args, **kwargs):
-        pub_views = getattr(conf, 'STRONGHOLD_PUBLIC_URLS', ())
-        self.public_view_urls = [re.compile(v) for v in pub_views]
+        self.public_view_urls = getattr(conf, 'STRONGHOLD_PUBLIC_URLS', ())
 
     def process_view(self, request, view_func, view_args, view_kwargs):
         # if request is authenticated, dont process it
